#
# spec file for package gucharmap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define api_version 2.90
%define so_api _2_90
%define so_gucharmap 7
%define pc_api 2.90
Name:           gucharmap
Version:        16.0.2
Release:        1.6
Summary:        A Featureful Unicode Character Map
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Gucharmap
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  appdata-tools
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gobject-introspection-devel >= 0.9.0
BuildRequires:  gtk-doc
BuildRequires:  gtk3-devel >= 3.4.0
BuildRequires:  intltool
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  unicode-ucd >= 16.0.0
BuildRequires:  unicode-ucd-unihan
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gio-2.0) >= 2.32.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
Recommends:     %{name}-doc

%description
Gucharmap is a featureful unicode character map.

%package -n libgucharmap%{so_api}-%{so_gucharmap}
Summary:        A Featureful Unicode Character Map -- Library
Group:          System/GUI/GNOME

%description -n libgucharmap%{so_api}-%{so_gucharmap}
Gucharmap is a featureful unicode character map.

This package contains a library to use the character map.

%package -n typelib-1_0-Gucharmap-2_90
Summary:        A Featureful Unicode Character Map -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gucharmap-2_90
Gucharmap is a featureful unicode character map.

This package provides the GObject Introspection bindings for the
gucharmap library.

%package devel
Summary:        A Featureful Unicode Character Map -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgucharmap%{so_api}-%{so_gucharmap} = %{version}
Requires:       typelib-1_0-Gucharmap-2_90 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%lang_package

%prep
%autosetup -p1

%build
export LIBS="-ldl"
%meson \
    -Ducd_path=%{_datadir}/unicode/ucd \
    %{nil}
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
# We need X-SuSE-Editor to avoid an error for the categories check. We don't
# want TextEditor, since that's too wide.
%suse_update_desktop_file -N "GNOME Character Map" -G "Character Map" %{name} X-SuSE-Editor
%fdupes -s %{buildroot}%{_datadir}

%post -n libgucharmap%{so_api}-%{so_gucharmap} -p /sbin/ldconfig
%postun -n libgucharmap%{so_api}-%{so_gucharmap} -p /sbin/ldconfig

%files
%license COPYING COPYING.GFDL COPYING.UNICODE
%doc README.md
%{_bindir}/gucharmap
%{_datadir}/applications/gucharmap.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Charmap.gschema.xml
%doc %{_datadir}/help/C/gucharmap/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/gucharmap.metainfo.xml

%files -n libgucharmap%{so_api}-%{so_gucharmap}
%{_libdir}/libgucharmap%{so_api}.so.%{so_gucharmap}*

%files -n typelib-1_0-Gucharmap-2_90
%{_libdir}/girepository-1.0/Gucharmap-2.90.typelib

%files lang -f %{name}.lang

%files devel
%{_includedir}/gucharmap-%{pc_api}/
%{_libdir}/libgucharmap%{so_api}.so
%{_libdir}/pkgconfig/gucharmap-%{pc_api}.pc
%{_datadir}/gir-1.0/Gucharmap-%{pc_api}.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gucharmap-2.90.deps
%{_datadir}/vala/vapi/gucharmap-2.90.vapi
%doc %{_datadir}/gtk-doc/html/gucharmap-%{pc_api}/

%changelog
* Tue Nov 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 16.0.2:
  + Updated documentation.
  + Updated translations.
* Mon Oct 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 16.0.1:
  + unicode: Update strings in preparation for unicode 16.0.0.
  + Updated translations.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Tue Jun 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 15.1.5:
  + Updated translations.
* Tue May 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 15.1.4:
  + Updated translations.
* Wed Mar 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 15.1.3:
  + Updated translations.
* Thu Jan  4 2024 dimstar@opensuse.org
- Update to version 15.1.2:
  + Updated translations.
* Wed Oct  4 2023 bjorn.lie@gmail.com
- Update to version 15.1.1:
  + DOAP: Remove defunct mailing list; add Discourse
  + unicode: Update to version 15.1.0
  + unicode: i18n update for 15.1.0
  + metainfo: Add launchable info
  + Updated translations.
- Update source service to current standard.
* Tue May  2 2023 dimstar@opensuse.org
- Update to version 15.0.4:
  + Update application screenshots to version 15.
  + unicode: Derive some more character names.
  + Updated translations.
* Wed Dec 14 2022 dimstar@opensuse.org
- Update to version 15.0.2:
  + metainfo: Add screenshots and link them from metainfo.
  + build: Use GNOME module post_install().
  + all: Update to unicode 15.0.0.
  + Updated translations.
* Wed May 18 2022 dimstar@opensuse.org
- Update to version 14.0.3:
  + Classify characters without script name properly
  + all: Use PCRE2 instead of GRegex
  + build:
  - Enforce required unicode data version
  - Fix build with meson 0.60
  - Fix warning about incompatible pointer return type
  - Fix warning about unused variable 'priv'
  - Remove unwanted warning
  + charmap: Search in details by default
  + chartable:
  - Improve Korean Hanja Pronunciations property
  - Mark special script and block names in italic
  - Use device scale for character popup
  + help: Remove duplicate entry
  + lib:
  - Enable alphabetical sorting of the Unicode blocks
  - Remove bogus volatile from type builtins code
  + unicode:
  - Add strings to prepare unicode 14 update
  - Update for unicode 14.0.0
  + Updated translations.
- Drop a8ee037f8cf151b8b65354bc93c56953e41f5a22.patch: fixed
  upstream.
* Thu Feb  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add a8ee037f8cf151b8b65354bc93c56953e41f5a22.patch: Fix build
  with meson 0.61 and newer.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Mar 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 13.0.0 (no changelog)
- Switch to _service and _servicedata because tarball wasn't released
- Switch to meson
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 12.0.1:
  + checksums: Update for unicode 12.0.0.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 12.0.0:
  + unicode:
  - Update to version 12.0.0.
  - Fix name buffer length.
  + help: Update screenshots for GNOME 3.32.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 11.0.3:
  + No upstream changes or NEWS provided, please see upstream git:
    https://gitlab.gnome.org/GNOME/gucharmap
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 jengelh@inai.de
- Drop ineffective --with-pic. Replace fragile LDFLAGS=-ldl.
* Tue Mar 13 2018 dimstar@opensuse.org
- export LDFLAGS="-ldl": upstream forgot to link libdl, which is
  needed for dlsyms (bgo#794281).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 10.0.4:
  + charmap: Improve glyph display.
  + charmap: Always show the scroll bar (bgo#791715, bgo#791931).
  + Updated translations.
- Add pkgconfig(freetype2) BuildRequires: new dependency.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Nov  2 2017 luc14n0@linuxmail.org
- Update Url to https://wiki.gnome.org/Apps/Gucharmap: current
  Gucharmap's web page.
- Add pkgconfig(glib-2.0) BuildRequires: missing declaration of
  dependency, it was already being used thanks to
  pkgconfig(gio-2.0) BuildRequires that lives in the same devel
  package that provides glib-2.0.
- Drop perl(Env) and libxml2-tools BuildRequires since they are not
  being used or needed.
- Points fdupes to removal of duplicates under the data directory
  rather than the whole build root.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 10.0.3:
  + Upgrade some links to https.
  + Updated translations.
- Drop glib2_gsettings_schema_* and desktop_database_* post/postun
  scriptlets: the functionality is covered by file triggers now.
* Thu Oct  5 2017 zaitor@opensuse.org
- Update to version 10.0.2:
  + help:
  - Remove unused translated screenshots.
  - Fix missing image.
  + Add Polish help screenshots.
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 10.0.1:
  + Updated translations.
* Wed Jun 21 2017 dimstar@opensuse.org
- Update to version 10.0.0:
  + Unicode: Prepare update to unicode 10.0.0.
  + Updated translations.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 9.0.4:
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 9.0.3:
  + Bugs fixed: bgo#539093, bgo#741939#c28, bgo#777829.
  + Updated translations.
- Drop gucharmap-no-force-light-theme.patch: fixed upstream.
* Tue Jan 24 2017 zaitor@opensuse.org
- Add gucharmap-no-force-light-theme.patch: No longer force light
  theme variant, patch from upstream git.
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 9.0.2:
  + Add korean hangul and vietnamese pronunciations (bgo#773380).
  + Updated translations.
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 9.0.1:
  + a11y: Fix introspection dump.
  + Updated translations.
- Changes from version 9.0.0
  + Update to Unicode 9.0.0 release.
- Changes from version 8.0.0:
  + Gucharmap no longer includes Unicode data. Instead the data is
    generated a build time from the unicode source data, which can
    either be downloaded from unicode.org, or be provided in a
    directory specified by the --with-unicode-data=DIRECTORY
    configure switch.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Stop passing V=1, we do debugging locally.
- Drop scrollkeeper BuildRequires, and stop passing
  - -disable-scrollkeeper to configure, no longer needed nor
  recognized.
- Add gettext, unicode-ucd, unicode-ucd-unihan, unzip and perl(env)
  BuildRequires: New dependencies.
- Pass --with-unicode-data to configure following upstreams
  changes.
- Drop old FIXME note that is not applicable anymore.
* Mon May  2 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Update to Unicode 8.0.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + unicode:
  - Update to Unicode 8.0.0 release.
  - Fix gucharmap_get_unicode_name for Unicode 8.0.
  + charmap:
  - Remove unused code.
  - Suppress deprecated object property warnings (bgo#749195).
  + Updated translations.
* Mon May 11 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + charmap: Fix build with gtk+ < 3.16 (bgo#749141).
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + build: Remove appdata validation.
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Fix menubar visibility.
  + Disable glib and gtk deprecation warnings.
  + Disable overlay scrolling.
  + Bugs fixed: bgo#741939.
  + Updated translations.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 3.15.0:
  + Revert "Also sort the block chapters list".
  + Revert "Sort the tree view column, not the model directly".
  + Revert "Use locale-aware string comparision to sort the
    chapters".
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + No changes, version bump only.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + settings: Only save to dconf on exit (bgo#734191).
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Unicode: Update for unicode 7.0.0 release.
  + Updated translations.
- Add appdata-tools BuildRequires: new dependency to validate
  appdate file.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Add a appdata file.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#849913):
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.9.99:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix action / settings interaction (bgo#686820).
  + Update to latest unicode data.
  + Updated translations.
* Sun Jul 28 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Build fixes.
  + Update to unicode 6.3.0 beta.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fix the build with vala 0.20
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + vala: Fix build with vala 0.20 (bgo#697027).
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Bug fixes.
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Add keywords to the desktop file.
  + Introspection fixes.
  + Bugs fixed: bgo#678311, bgo#686612, bgo#695979.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Bug fixes.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.5.99:
  + Look for help files in the right location
  + Updated translations.
- Drop gnome-doc-utils-devel BuildRequires: no longer needed.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + unicode: Update to latest 6.2.0 beta
  + Port to new documentation infrastructure
- Add yelp-tools BuildRequires. Note: gnome-doc-utils is still
  needed for some other parts.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Update to Unicode 6.2.0 beta
  + Rearrange menus
  + Updated translations.
* Sat Jun  9 2012 dimstar@opensuse.org
- Update to version 3.5.0:
  + Add an application menu (bgo#674952)
  + Port to the new GMenu API (bgo#674952)
  + ui: Use GResource instead of string (bgo#674952)
  + main: Port to GtkApplication (bgo#674952)
- Add libxml2-tools BuildRequires for xmllint.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1.1:
  + No changes.
- Changes from version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + No changes.
- Changes from version 3.4.0:
  + Revert unintentional API/ABI break.
  + Build fixes.
  + Updated translations.
- Drop gucharmap-fix-pkg-config.patch: fixed upstream.
* Thu Feb  9 2012 vuntz@opensuse.org
- Add gucharmap-fix-pkg-config.patch: fix broken pkg-config file
  after move to GSettings.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.1:
  + Updated to Unicode 6.1.0
  + Ported to GSettings
  + Misc cleanup and bug fixes
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Remove gconf2-devel BuildRequires.
- Replace gconf packaging machinery with %%glib2_gsettings_schema_*
  macros.
- Remove checks for old non-maintained versions of openSUSE (<=
  11.2)
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.0:
  + Update to Unicode 6.1.0 (beta).
  + Use new workarea API.
  + Don't allow the charmap side pane to shrink too much.
  + Use attributes for deprecation.
  + Build fixes.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Gucharmap-2_90 subpackage.
- Add typelib-1_0-Gucharmap-2_90 Requires to devel subpackage.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Distribute the script to generate the unicode tables.
  + Updated translations.
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Drop gtk2 support.
  + Bug fixes.
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Updated translations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated to Unicode 6.0.0
  + Support building with gtk+ 3.0
  + Update introspection support, and add annotations
  + Many bug fixes.
  + Updated translations.
- Add rpm defines to help monitor soname / api version changes.
- Drop python binding subpackage (python-gucharmap), as this is now
  handled by introspection. This means we can remove the
  python-gtk-devel BuildRequires
- Add gobject-introspection-devel BuildRequires and pass
  - -enable-introspection to configure
- Build with gtk3:
  + Replace gtk2-devel BuildRequires with gtk3-devel
  + Pass --with-gtk=3.0 to configure
- Use _smp_mflags macro.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Thu Dec 23 2010 vuntz@opensuse.org
- Split libgucharmap7 and python-gucharmap subpackages, to respect
  shared library packaging policy.
- Improve summary and description.
- Remove unneeded gconf2-devel, glib2-devel, gtk2-devel Requires in
  devel package: they will automatically be added the pkgconfig()
  way.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + bgo#624929: Fix crash on searching.
  + bgo#634353: Changed access key.
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sun Aug 29 2010 dimstar@opensuse.org
- Update to version 2.31.91:
  + bgo#627144: Character extraction needs to be redone. Properly.
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Gucharmap is now licensed under GPL 3 or later
  + bgo#612487: fix build with -GSEAL_ENABLED
  + bgo#621215: type ahead search in tree view doesn't match
    translation
  + bgo#623435: fix build with newer gtk versions
  + bgo#624980: fix build system
  + Updated translations.
- Update License tag to "GPLv3+; LGPLv2.1+"
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.30.2:
  + Search the tree view column instead of the model.
  + Updated translations.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Minor bug fixes
  + updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated API documentation.
  + Updated translations.
* Tue Mar 23 2010 dimstar@opensuse.org
- Remove en@shaw locale on openSUSE <= 11.2.
* Thu Mar 11 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + bgo#602994: Don't use PYTHON_LOCALMODLIBS as it can break the
    build
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + Updated to Unicode 5.2.0
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Add Pulse status to documentation
  + respect the button-images setting
  + Updated translations.
* Mon Sep 14 2009 aj@suse.de
- Remove obsolete requires on libgnome and libgnomeui (obsolete since
  2.21.4)
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.26.3.1:
  + Build fix.
- Changes from version 2.26.3:
  + Updated translations.
* Tue May 19 2009 vuntz@novell.com
- Update to version 2.26.2:
  + Updated translations.
* Mon Apr 13 2009 mboman@suse.de
- Update to version 2.26.1:
  + floating point exception using --font
  + Incorrect comment for gucharmap_charmap_set_font_desc
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
- Don't package omf files twice (they are in the lang package too).
* Mon Mar  9 2009 vuntz@novell.com
- Add back scrollkeeper BuildRequires since some translations were
  not ported to gnome-doc-utils.
* Tue Feb 17 2009 mboman@suse.de
- Merge omf/gucharmap back to main packages. Makes no sense to have
  a separate -doc package only for this.
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.25.91:
  +  gucharmap doesn't build with --disable-gconf
- Remove gucharmap-abuild.patch. Code commented out
- Move gtk-doc from -doc into -devel
- Move omf/gucharmap from main into -doc
- Remove gnome-common, libgnomeui-devel, scrollkeeper, docbook_4
  from BuildRequires
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2.24.3:
  + Call g_thread_init() if using GConf.
  + Allow gucharmap to build with --disable-gconf, bgo#562931.
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Fri Jan 23 2009 vuntz@novell.com
- Drop gucharmap-desktop.patch, and set the name with
  %%suse_update_desktop_file
- Drop gucharmap-no-root.patch: it shouldn't be needed anymore.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.24.2:
  + Fix a crash when pasting with no text on the clipboard
  + Translation update
* Wed Oct 22 2008 mboman@suse.de
- Update to version 2.24.1:
  + Translation updates
* Fri Oct  3 2008 vuntz@novell.com
- Fix build by removing the call to autoreconf. It somehow breaks
  stuff by not generating libtool early enough...
- Create a doc package for the library documentation.
  Add gtk-doc dependency.
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  + Plug a mem leak.
  + Use single / in the help file path.
  + Use gtk_show_uri here.
  + Use GIO to launch the help URI instead of calling gnome-open.
  + Updated translations.
* Mon Aug 11 2008 maw@suse.de
- Update to version 2.23.6:
  + Misc. changes
  + Updated translations.
* Wed Jun 25 2008 maw@suse.de
- Update to version 2.23.4:
  + API change: the pkg-config name is now gucharmap-2
  + Support for Unicode 5.1
  + gtk-doc API docs
  + Python bindings
  + Many bug fixes
- Add gucharmap-abuild.patch.
* Fri Apr 11 2008 maw@suse.de
- Update to version 2.22.1:
  + Bug fixed: bgo#506752.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Cosmetic version bump.
* Fri Feb 29 2008 maw@suse.de
- Make the %%clean section do something again.
* Fri Feb 29 2008 maw@suse.de
- Update to version 2.21.90:
  + Fix bgo#510813
  + Fix the installed .pc file, which contained some bogosities.
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.5:
  + Fix character popup sizing (bnc#501915)
  + Fix the build with --disable-gconf (bnc#501710)
  + Remove gnome option (bnc#469131)
  + Translation updates
- Remove gucharmap-glib-breakage.patch because it's no longer
  necessary.
* Thu Dec 20 2007 maw@suse.de
- Add gucharmap-glib-breakage.patch (#350152).
* Thu Dec 20 2007 maw@suse.de
- Update to version 2.21.4:
  + The large version bump is gucharmap synchronizing its version
    number with that of GNOME
  + Bugs (bugzilla.gnome.org) fixed: #501915, #331103, #501710,
    [#469131]
  + Install gconf schemas
- Remove bogus dependencies
- Remove bogus stuff in %%post and %%postun.
* Wed Sep 19 2007 mauro@suse.de
- Update to version 1.10.1
- Bugfixes for bgo: #311912, #357471, #396265, #434276, #433134
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Mon May 14 2007 pgajdos@suse.cz
- removed gnome-icon-theme from Requires and BuildRequires
  [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Mon Apr  9 2007 maw@suse.de
- Update to version 1.10.0
- Now requires a newer version of libtool.
* Fri Mar  9 2007 maw@suse.de
- Update to version 1.9.0.
  - Updated build system.
  - Updated translations.
* Fri Mar  9 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Mon Jan  8 2007 sbrabec@suse.cz
- Spec file cleanup.
* Fri Dec 15 2006 maw@suse.de
- Move to /usr.
* Thu Oct 12 2006 ro@suse.de
- added gnome-doc-utils-devel to buildreq
* Sat Sep 30 2006 aj@suse.de
- Cleanup BuildRequires.
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 1.8.0
- Small fixes and new translations
* Tue Aug 15 2006 jhargadon@suse.de
- update to version 1.7.0
- Bug 341260 – String "Snap Columns to Power of Two" not marked for
  translation
- Bug 334505 – Search buttons Prev Next unsensitive when they
  shouldn't be.
- Bug 335952 – refcount leak in main
- Bug 334865 – tiny string leak
- Bothersome gucharmap input method removed.
- updated translations
* Fri May  5 2006 sreeves@suse.de
- Fix for 167218 - change name
* Wed Apr 26 2006 sreeves@suse.de
- Fix for 168664 - move from the Images category
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Sat Feb 18 2006 gekker@suse.de
- fixup .desktop file for UI team
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep  7 2005 sbrabec@suse.cz
- Updated to version 1.4.4 (GNOME 2.12).
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Mar  9 2005 gekker@suse.de
- Update to 1.4.3 (GNOME 2.10).
- Remove upstreamed cs.po patch
* Thu Feb 24 2005 sbrabec@suse.cz
- Fixed typos in cs.po.
* Tue Dec 21 2004 gekker@suse.de
- Update to version 1.4.2
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Mon Nov 22 2004 ro@suse.de
- "sed -i" does not work on old distributions
* Tue Oct 19 2004 sbrabec@suse.cz
- Renamed no locale to nb.
* Fri Aug 27 2004 clahey@suse.de
- Cache gucharmap help and show gucharmap in khelpcenter.
* Fri May 14 2004 clahey@suse.de
- Removed gucharmap-immodules.dif because gucharmap no longer
  searches for immodules.
* Wed Apr 21 2004 sbrabec@suse.cz
- Updated to version 1.4.1 (GNOME 2.6).
* Wed Mar 10 2004 sbrabec@suse.cz
- Czech typo fixes.
* Mon Mar  8 2004 hhetter@suse.de
- search for gtk-query-immodules-2.0-64 on x86_64
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 1.2.0.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Oct  9 2003 sbrabec@suse.cz
- Updated to version 1.0.0 (GNOME 2.4).
* Fri Sep  5 2003 sbrabec@suse.cz
- Added %%run_ldconfig to postun (bug #29417).
* Thu Aug 21 2003 ro@suse.de
- autoreconf for successful build on lib64
* Wed Aug 20 2003 sbrabec@suse.cz
- Added run-gtk to %%post and %%postun.
* Tue Aug 19 2003 sbrabec@suse.cz
- Initial SuSE version 0.8.0.
